==> haskell-language-javascript-0.6.0.10-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-language-javascript.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-javascript
version: 0.6.0.10
id: language-javascript-0.6.0.10-1S5Jj2C36PRBc01JV0pCfz
key: language-javascript-0.6.0.10-1S5Jj2C36PRBc01JV0pCfz
license: BSD3
copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
homepage: https://github.com/erikd/language-javascript
synopsis: Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.
    .
    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.
category: Language
author: Alan Zimmerman
exposed: True
indefinite: False
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.AST
    Language.JavaScript.Parser.Grammar5
    Language.JavaScript.Parser.Lexer Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.SrcLocation
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Process.Minify
hidden-modules: Language.JavaScript.Parser.LexerUtils
                Language.JavaScript.Parser.ParseError
                Language.JavaScript.Parser.ParserMonad
                Language.JavaScript.Parser.Token
abi: 33df8301fea6dba9bc90cf639cb0f009
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/language-javascript-0.6.0.10
library-dirs: /usr/lib/ghc-8.2.2/site-local/language-javascript-0.6.0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/language-javascript-0.6.0.10
hs-libraries: HSlanguage-javascript-0.6.0.10-1S5Jj2C36PRBc01JV0pCfz
depends:
    base-4.10.1.0 array-0.5.2.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    containers-0.5.10.2 blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    bytestring-0.10.8.2 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
haddock-interfaces: /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock
haddock-html: /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-javascript-0.6.0.11-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-language-javascript.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-javascript
version: 0.6.0.11
id: language-javascript-0.6.0.11-6yTrtHlze5G5jfn5hvfLcs
key: language-javascript-0.6.0.11-6yTrtHlze5G5jfn5hvfLcs
license: BSD3
copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
homepage: https://github.com/erikd/language-javascript
synopsis: Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.
    .
    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.
category: Language
author: Alan Zimmerman
exposed: True
indefinite: False
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.AST
    Language.JavaScript.Parser.Grammar5
    Language.JavaScript.Parser.Lexer Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.SrcLocation
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Process.Minify
hidden-modules: Language.JavaScript.Parser.LexerUtils
                Language.JavaScript.Parser.ParseError
                Language.JavaScript.Parser.ParserMonad
                Language.JavaScript.Parser.Token
abi: 0079c859c26c612a35bdc60e19f5e7de
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/language-javascript-0.6.0.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/language-javascript-0.6.0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/language-javascript-0.6.0.11
hs-libraries: HSlanguage-javascript-0.6.0.11-6yTrtHlze5G5jfn5hvfLcs
depends:
    base-4.10.1.0 array-0.5.2.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    containers-0.5.10.2 blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    bytestring-0.10.8.2 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
haddock-interfaces: /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock
haddock-html: /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
